==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Block/ts/Block_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>Block</name>
    <message>
        <location filename="../Block.js" line="+67"/>
        <source>Block Tools</source>
        <translation>ブロックツール</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show block tools</source>
        <translation>表示ブロックツール</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Block</source>
        <translation>&amp;B ブロック</translation>
    </message>
</context>
<context>
    <name>BlockDialog</name>
    <message>
        <location filename="../BlockDialog.js" line="+115"/>
        <source>Leading or trailing spaces.</source>
        <translation>上部または下部の余白。</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is empty.</source>
        <translation>ブロック名が空です。</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is invalid.</source>
        <translation>ブロック名が無効です。</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Block &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block already exists.</source>
        <translation>ブロックは既に存在します。</translation>
    </message>
    <message>
        <location filename="../BlockDialog.ui" line="+17"/>
        <source>Block Data</source>
        <translation>ブロックデータ</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Block name:</source>
        <translation>ブロック名:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>block 1</source>
        <translation>ブロック１</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Block/ts/Block_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>Block</name>
    <message>
        <location filename="../Block.js" line="+67"/>
        <source>Block Tools</source>
        <translation>ブロックツール</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show block tools</source>
        <translation>表示ブロックツール</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Block</source>
        <translation>&amp;B ブロック</translation>
    </message>
</context>
<context>
    <name>BlockDialog</name>
    <message>
        <location filename="../BlockDialog.js" line="+134"/>
        <source>Leading or trailing spaces.</source>
        <translation>上部または下部の余白。</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is empty.</source>
        <translation>ブロック名が空です。</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is invalid.</source>
        <translation>ブロック名が無効です。</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Block &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation>ブロック &apos;%1&apos;は既に存在します。&lt;br&gt;そのため上書きされます。</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block already exists.</source>
        <translation>ブロックは既に存在します。</translation>
    </message>
    <message>
        <location filename="../BlockDialog.ui" line="+17"/>
        <source>Block Data</source>
        <translation>ブロックデータ</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Block name:</source>
        <translation>ブロック名:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>block 1</source>
        <translation>ブロック１</translation>
    </message>
</context>
<context>
    <name>LayoutDialog</name>
    <message>
        <source>Leading or trailing spaces.</source>
        <translation type="obsolete">上部または下部の余白。</translation>
    </message>
</context>
</TS>
